/*

  This file is part of OpenFLUID software
  Copyright(c) 2007, INRA - Montpellier SupAgro


 == GNU General Public License Usage ==

  OpenFLUID is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  OpenFLUID is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with OpenFLUID. If not, see <http://www.gnu.org/licenses/>.


 == Other Usage ==

  Other Usage means a use of OpenFLUID that is inconsistent with the GPL
  license, and requires a written agreement between You and INRA.
  Licensees for Other Usage of OpenFLUID may use this file in accordance
  with the terms contained in the written agreement between You and INRA.

 */

/**
  @file ElidedLabel.hpp

  @author Jean-Christophe FABRE <jean-christophe.fabre@inra.fr>
 */


#ifndef __OPENFLUID_UICOMMON_ELIDEDLABEL_HPP__
#define __OPENFLUID_UICOMMON_ELIDEDLABEL_HPP__


#include <QLabel>

#include <openfluid/dllexport.hpp>


namespace openfluid { namespace ui { namespace common {


/**
  Single line elided label class, based on QLabel
*/
class OPENFLUID_API ElidedLabel : public QLabel
{
  Q_OBJECT

  private:

    QString m_CachedElidedText;

    Qt::TextElideMode m_ElideMode;


  protected:

    void paintEvent(QPaintEvent *Ev);

    void resizeEvent(QResizeEvent *Ev);


  protected:

    void cacheElidedText(int w);


  public:

    ElidedLabel(QWidget* Parent = nullptr, Qt::WindowFlags Flags=0);

    ElidedLabel(const QString& Text, QWidget* Parent = nullptr, Qt::WindowFlags Flags = 0);

    ElidedLabel(const QString& Text, Qt::TextElideMode ElideMode = Qt::ElideRight,
                QWidget* Parent = nullptr, Qt::WindowFlags Flags = 0);

    virtual ~ElidedLabel()
    { }

    void setElideMode(Qt::TextElideMode ElideMode);

    Qt::TextElideMode getElideMode() const
    { return m_ElideMode; }

    void setText(const QString& Text);
};


} } } // namespaces


#endif /* __OPENFLUID_UICOMMON_ELIDEDLABEL_HPP__ */
