/*

  This file is part of OpenFLUID software
  Copyright(c) 2007, INRA - Montpellier SupAgro


 == GNU General Public License Usage ==

  OpenFLUID is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  OpenFLUID is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with OpenFLUID. If not, see <http://www.gnu.org/licenses/>.


 == Other Usage ==

  Other Usage means a use of OpenFLUID that is inconsistent with the GPL
  license, and requires a written agreement between You and INRA.
  Licensees for Other Usage of OpenFLUID may use this file in accordance
  with the terms contained in the written agreement between You and INRA.
  
*/


/**
  @file MessageFrame.cpp

  @author Jean-Christophe FABRE <jean-christophe.fabre@inra.fr>
*/


#include <openfluid/ui/config.hpp>
#include <openfluid/ui/common/MessageFrame.hpp>

#include "ui_MessageFrame.h"


namespace openfluid { namespace ui { namespace common {


MessageFrame::MessageFrame(QWidget* Parent, const QString& DefaultMsg):
  QFrame(Parent), ui(new Ui::MessageFrame), m_DefaultMsg(DefaultMsg)
{
  ui->setupUi(this);

  ui->MessageLabel->setStyleSheet("color: #ffffff; font : bold;");
  ui->MessageLabel->setText(m_DefaultMsg);

  setStyleSheet(QString("background-color: %1;").arg(openfluid::ui::config::DIALOGBANNER_BGCOLOR));
  setMinimumHeight(40);
}


// =====================================================================
// =====================================================================


MessageFrame::~MessageFrame()
{
  delete ui;
}


// =====================================================================
// =====================================================================


void MessageFrame::updateDefaultMessage(const QString& Msg)
{
  m_DefaultMsg = Msg;
}


// =====================================================================
// =====================================================================


void MessageFrame::setMessage(const QString& Msg)
{
  if (Msg.isEmpty())
  {
    setStyleSheet(QString("background-color: %1;").arg(openfluid::ui::config::DIALOGBANNER_BGCOLOR));
    ui->MessageLabel->setText(m_DefaultMsg);
  }
  else
  {
    setStyleSheet(QString("background-color: %1;").arg(openfluid::ui::config::DIALOGBANNER_WARNBGCOLOR));
    ui->MessageLabel->setText(Msg);
  }
}


} } } // namespaces

